abacusai.api_endpoint — AbacusAI documentation

# `abacusai.api_endpoint`

## Module Contents

### Classes

`ApiEndpoint` | An collection of endpoints which can be used to make requests to, such as api calls or predict calls

class abacusai.api_endpoint.ApiEndpoint(client, apiEndpoint=None, predictEndpoint=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  An collection of endpoints which can be used to make requests to, such as api calls or predict calls

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - apiEndpoint (str) – The URI that can be used to make API calls

    - predictEndpoint (str) – The URI that can be used to make predict calls against Deployments

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict